#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-quickcheck
version:              0.11.1
visibility:           public
id:                   tasty-quickcheck-0.11.1-9a1B2V5KkVnCrjxfEPojfY
key:                  tasty-quickcheck-0.11.1-9a1B2V5KkVnCrjxfEPojfY
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.

category:             Testing
abi:                  44b7d7b32c273d0a792f3cebaeb1e3d1
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.11.1-9a1B2V5KkVnCrjxfEPojfY
depends:
    QuickCheck-2.15.0.1-K1K5d21alyXTYmRpvOX4I base-4.18.2.1
    optparse-applicative-0.18.1.0-1GTn8byg6tu7aER5UFeikt
    random-1.2.1.3-9N1SQpnyQhUKkZ8H2hXCDf
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-COAfT6a03JnHgIISmSb09C

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

